/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.itvsh.kop.common.logging;

import de.itvsh.kop.common.logging.logger.AspectLogger;
import de.itvsh.kop.common.logging.logger.InterceptingLogger;
import jakarta.interceptor.InvocationContext;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.aspectj.lang.JoinPoint;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class AspectLoggingUtils {

	public static void log(final JoinPoint joinPoint) {
		new AspectLogger(joinPoint).log();
	}

	public static void log(InvocationContext context) {
		new InterceptingLogger(context).log();
	}

	public static void logException(JoinPoint joinPoint, Exception exception) {
		new AspectLogger(joinPoint).logException(exception);
	}

	public static void logException(InvocationContext context, Exception exception) {
		new InterceptingLogger(context).logException(exception);
	}

	public static void logReturnValue(JoinPoint joinPoint, Object returnValue) {
		new AspectLogger(joinPoint).logReturnValue(returnValue);
	}

	public static void logReturnValue(InvocationContext context, Object returnValue) {
		new InterceptingLogger(context).logReturnValue(returnValue);
	}

}